16.87. cdist-type__keyboard(7) — cdist 6.9.8 documentation

# 16.87. cdist-type__keyboard(7)

## 16.87.1. NAME

cdit-type__keyboard - Set keyboard layout

## 16.87.2. DESCRIPTION

This cdist type allows you to modify keyboard layout.

## 16.87.3. REQUIRED PARAMETERS

type

  Any valid type, for example "us"

## 16.87.4. EXAMPLES

    # Set keyboard type to "us"
    __keyboard --type "us"

## 16.87.5. AUTHORS

Carlos Ortigoza <carlos.ortigoza--@--ungleich.ch>

## 16.87.6. COPYING

Copyright (C) 2016 Carlos Ortigoza. Free use of this software is granted under the terms of the GNU General Public License v3 or later (GPLv3+).